{{objname}}
{{ underline }}===============

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :special-members: __call__

.. include:: {{module}}.{{objname}}.examples

.. raw:: html

    <div class="clearer"></div>
